<!DOCTYPE html>
<html>
<head>
    <meta charset="utf-8" />
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <title>Plugin</title>
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <!-- Bootstrap 3.3.7 -->
    <link href="/plugin/static/plugins/bootstrap/bootstrap.min.css" rel="stylesheet">
    <!-- Font Awesome -->
    <link href="/plugin/static/css/font-awesome.min.css" rel="stylesheet">
    <!-- Ionicons -->
    <link href="/plugin/static/css/ionicons.min.css" rel="stylesheet">
    <!-- Theme style -->
    <link href="/plugin/static/css/AdminLTE.css" rel="stylesheet" type="text/css"/>
    <!-- AdminLTE Skins. Choose a skin from the css/skins
         folder instead of downloading all of them to reduce the load. -->
    <link rel="stylesheet" href="/plugin/static/css/skins/_all-skins.css">
    <!-- Morris chart -->
    <link href="/plugin/static/plugins/morris/morris.css" rel="stylesheet">
    <!-- jvectormap -->
    <link href="/plugin/static/plugins/jvectormap/jquery-jvectormap.min.css" rel="stylesheet">
    <!-- Date Picker -->
    <link href="/plugin/static/plugins/bootstrap-datepicker/bootstrap-datepicker.min.css" rel="stylesheet">
    <!-- Daterange picker -->
    <link href="/plugin/static/plugins/daterangepicker/daterangepicker.min.css" rel="stylesheet">
    <!-- bootstrap wysihtml5 - text editor -->
    <link rel="stylesheet" href="/plugin/static/plugins/bootstrap-wysihtml5/bootstrap3-wysihtml5.min.css">
    <!-- DataTable -->
    <link rel="stylesheet" href="/plugin/static/css/dataTables.bootstrap.min.css">
    <link rel="stylesheet" href="/plugin/static/plugins/jsonview/jquery.jsonview.css">
    <!-- JsonEditor -->
    <link href="/plugin/static/plugins/jsoneditor/jsoneditor.min.css" rel="stylesheet">

    <link rel="stylesheet" href="/plugin/static/js/iview/styles/iview.css">
    <!-- Google Font -->
    <link rel="stylesheet" href="/plugin/static/css/fonts-googleapis.css">
    [% block link %]
        [% for css in plugin_css %]
            [[ css|safe ]]
        [% endfor %]
    [% endblock%]
</head>
<body style="background-color: transparent">

    [% block content %]
    [[ plugin_content|safe ]]
    [% endblock %]


    <!-- jQuery 3 -->
    <script src="/plugin/static/js/jquery.min.js"></script>
    <script src="/plugin/static/js/jquery-ui.min.js"></script>

    <!-- Bootstrap 3.3.7 -->
    <script src="/plugin/static/plugins/bootstrap/bootstrap.min.js"></script>
    <!-- Morris.js charts -->
    <script src="/plugin/static/js/raphael.min.js"></script>
    <script src="/plugin/static/plugins/morris/morris.min.js"></script>
    <!-- Sparkline -->
    <script src="/plugin/static/js/jquery.sparkline.min.js"></script>
    <!-- jvectormap -->
    <script src="/plugin/static/plugins/jvectormap/jquery-jvectormap-1.2.2.min.js"></script>
    <script src="/plugin/static/plugins/jvectormap/jquery-jvectormap-world-mill-en.js"></script>
    <!-- jQuery Knob Chart -->
    <script src="/plugin/static/js/jquery.knob.min.js"></script>
    <!-- daterangepicker -->
    <script src="/plugin/static/plugins/daterangepicker/moment.min.js"></script>
    <script src="/plugin/static/plugins/daterangepicker/daterangepicker.min.js"></script>
    <!-- datepicker -->
    <script src="/plugin/static/plugins/bootstrap-datepicker/bootstrap-datepicker.min.js"></script>
    <!-- Bootstrap WYSIHTML5 -->
    <script src="/plugin/static/plugins/bootstrap-wysihtml5/bootstrap3-wysihtml5.all.min.js"></script>
    <!-- Slimscroll -->
    <script src="/plugin/static/js/jquery.slimscroll.min.js"></script>
    <!-- FastClick -->
    <script src="/plugin/static/js/fastclick.min.js"></script>
    <!-- DataTable -->
    <script src="/plugin/static/plugins/datatables/jquery.dataTables.min.js"></script>
    <script src="/plugin/static/plugins/datatables/dataTables.uikit.min.js"></script>
    <script src="/plugin/static/plugins/datatables/dataTables.semanticui.min.js"></script>
    <script src="/plugin/static/plugins/datatables/dataTables.material.min.js"></script>
    <script src="/plugin/static/plugins/datatables/dataTables.jqueryui.min.js"></script>
    <!-- JsonEditor -->
    <script src="/plugin/static/plugins/jsoneditor/jsoneditor.min.js"></script>
    <!-- Socket IO -->
    <script src="/plugin/static/js/socket.io.js"></script>
    <!-- AdminLTE App -->
    <script src="/plugin/static/js/adminlte.min.js"></script>
    <script src="/plugin/static/js/app.min.js"></script>
    <!-- lyrebird -->
    <script src="/plugin/static/js/lyrebird.js"></script>
    <!-- json view -->
    <script src="/plugin/static/plugins/jsonview/jquery.jsonview.js"></script>
    
    <script src="/plugin/static/js/vue.js"></script>
    <script src="/plugin/static/js/vuex.js"></script>
    <script src="/plugin/static/js/iview/iview.min.js"></script>
    <script src="/plugin/static/js/iview/locale/en-US.js"></script>
    <script src="/plugin/static/js/vue-resource.js"></script>
    <script src="/plugin/static/js/httpVueLoader.js"></script>
    <script src="/plugin/static/js/axios.min.js"></script>


    [% block scripts %]
    [% for script in plugin_javascript %]
        [[ script|safe ]]
    [% endfor %]
    [% endblock %]


</body>
</html>