#app{font-family:Avenir,Helvetica,Arial,sans-serif;-webkit-font-smoothing:antialiased;-moz-osx-font-smoothing:grayscale}.ivu-card>.ivu-card-head{padding:5px 5px 3px 5px;font-size:12px}.ivu-card>.ivu-card-body{padding:5px 5px 5px 8px;font-size:12px}.main-header-notice{float:right;margin-right:15px}.notice-badge{background:#ff7f55!important;-webkit-box-shadow:0 0 0 transparent!important;box-shadow:0 0 0 transparent!important;border:0!important;padding:0 3px!important;line-height:14px!important;height:14px!important}.ivu-drawer-right>.ivu-drawer-content{background:hsla(0,0%,90.2%,.8)}.ivu-drawer-content>.ivu-drawer-header{height:38px}.ivu-drawer-content>.ivu-drawer-body{padding:0}.main-layout[data-v-74a5a744]{height:100vh}.sider-bar[data-v-74a5a744]{background-color:#515a6e}.sider-bar-divider[data-v-74a5a744]{height:1px;margin:0;background:#6c6c6c}.logo[data-v-74a5a744]{height:38px;display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center}.logo span[data-v-74a5a744]{color:#fff;font-size:25px;font-weight:bolder;font-style:italic}.logo img[data-v-74a5a744]{width:32px}.main-header[data-v-74a5a744]{height:38px;line-height:38px;padding:0;margin:0;background-color:#0fccbf}.main-footer[data-v-74a5a744]{height:28px;line-height:28px;padding:0;background-color:#0fccbf}.main-footer-copyright[data-v-74a5a744]{font-size:12px;margin-left:15px;color:#f8f8f9}.main-footer-status[data-v-74a5a744]{float:right;font-size:11px;margin-right:10px}.collapsed-menu span[data-v-74a5a744]{width:0;-webkit-transition:width .2s ease;transition:width .2s ease}.menu-item span[data-v-74a5a744]{display:inline-block;overflow:hidden;width:69px;text-overflow:ellipsis;white-space:nowrap;vertical-align:bottom;-webkit-transition:width .2s ease .2s;transition:width .2s ease .2s}.main-container[data-v-74a5a744]{padding-left:5px;padding-right:5px;height:calc(100vh - 71px);background:#fff}.flow-list{height:calc(100vh - 114px);overflow-y:auto}.flow-detail{height:calc(100vh - 166px)}.small-tab>.ivu-tabs>.ivu-tabs-bar{margin-bottom:0}.inline[data-v-a56b1e34]{display:inline}.button-bar[data-v-a56b1e34]{-webkit-box-flex:1;-ms-flex-positive:1;flex-grow:1}.button-bar[data-v-906812e0]{height:38px;display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-ms-flex-align:center;align-items:center}.inspector-left[data-v-906812e0]{margin-right:0}.inspector-right[data-v-906812e0]{margin-left:5px}.divider[data-v-906812e0]{display:block;width:100%;height:1px;background:#eee;top:0;left:0}.split[data-v-906812e0]{display:block;position:absolute;top:0;bottom:0;left:50%;border:1px dashed #eee}.inline[data-v-6f4d25ff]{display:inline}.button-bar[data-v-6f4d25ff]{-webkit-box-flex:1;-ms-flex-positive:1;flex-grow:1;display:-webkit-box;display:-ms-flexbox;display:flex}.modal-data-list[data-v-6f4d25ff]{height:30vh;overflow-y:auto}.group-label[data-v-6f4d25ff]{margin-left:5px;margin-right:5px}.btn-bar button[data-v-6f4d25ff]{padding:0;font-size:18px;border-radius:0}.parent-name[data-v-6f4d25ff]{max-width:200px;text-overflow:ellipsis}.data-list{height:calc(100vh - 166px);overflow-y:auto;margin-right:0}.data-table td div,.data-table th div{padding-left:5px;padding-right:5px}.button-bar[data-v-861cb0ca]{margin-top:5px}.data-detail[data-v-861cb0ca]{height:calc(100vh - 180px)}.small-tab>.ivu-tabs>.ivu-tabs-bar[data-v-861cb0ca]{margin-bottom:0}.button-bar[data-v-0291f27f]{height:38px;display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-ms-flex-align:center;align-items:center}.container-left[data-v-0291f27f]{margin-right:0}.container-right[data-v-0291f27f]{margin-left:5px}.divider[data-v-0291f27f]{display:block;width:100%;height:1px;background:#eee;top:0;left:0}.split[data-v-0291f27f]{display:block;position:absolute;top:0;bottom:0;left:50%;border:1px dashed #eee}.plugin-frame{position:relative;height:100%;width:100%}